Description Usage Arguments Value Examples
Takes a local bam file and load it to the environment as an GAlignment object
1 |
file |
The path of the input file to read |
A GAlignmentPairs object
1 | x <- hic_import("example.bam")
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.